@@ -221,6 +221,8 @@ def _resolve_class(
     protos = protocols(cls, strict=strict)
     if hasattr(cls, SERDE_FLAGS_ATTR):
         pserde: SerdeFlags = getattr(cls, SERDE_FLAGS_ATTR)
+        if isinstance(pserde, dict):
+            pserde = SerdeFlags(**pserde)
         serde = pserde.merge(serde) if serde else pserde
     serde = serde or SerdeFlags()
     ns: Dict[str, Any] = {
@@ -346,22 +348,21 @@ def _get_setter(cls: Type, bases: Tuple[Type, ...] = None):
 @overload
 def typed(
     _cls_or_callable: _Type, *, delay: bool = False, strict: bool = None
-) -> Type[WrappedObjectT[_Type]]:
-    ...
+) -> Type[WrappedObjectT[_Type]]: ...
 
 
 @overload
 def typed(
     _cls_or_callable: _Func, *, delay: bool = False, strict: bool = None
-) -> _Func:
-    ...
+) -> _Func: ...
 
 
 @overload
 def typed(
     *, delay: bool = False, strict: bool = None
-) -> Union[Callable[[_Type], Type[WrappedObjectT[_Type]]], Callable[[_Func], _Func]]:
-    ...
+) -> Union[
+    Callable[[_Type], Type[WrappedObjectT[_Type]]], Callable[[_Func], _Func]
+]: ...
 
 
 def typed(
