@@ -79,6 +79,7 @@ __all__ = (
     "iscollectiontype",
     "isconstrained",
     "isdatetype",
+    "isdecimaltype",
     "isdescriptor",
     "isenumtype",
     "isfinal",
@@ -428,6 +429,28 @@ def istimedeltatype(obj: Type[ObjectT]) -> TypeGuard[Type[datetime.timedelta]]:
     return builtins.issubclass(util.origin(obj), datetime.timedelta)
 
 
+@lru_cache(maxsize=None)
+def isdecimaltype(obj: Type[ObjectT]) -> TypeGuard[Type[decimal.Decimal]]:
+    """Test whether this annotation is a Decimal object.
+
+    Parameters
+    ----------
+    obj
+
+    Examples
+    --------
+
+    >>> import typic
+    >>> import decimal
+    >>> from typing import NewType
+    >>> typic.isdecimaltype(decimal.Decimal)
+    True
+    >>> typic.isdecimaltype(NewType("Foo", decimal.Decimal))
+    True
+    """
+    return builtins.issubclass(util.origin(obj), decimal.Decimal)
+
+
 @lru_cache(maxsize=None)
 def isuuidtype(obj: Type[ObjectT]) -> TypeGuard[Type[uuid.UUID]]:
     """Test whether this annotation is a a date/datetime object.
@@ -610,8 +633,7 @@ def isfromdictclass(obj: Type[ObjectT]) -> TypeGuard[_FromDict]:
 
 
 class _FromDict(Protocol):
-    def from_dict(self, *args, **kwargs) -> _FromDict:
-        ...
+    def from_dict(self, *args, **kwargs) -> _FromDict: ...
 
 
 @lru_cache(maxsize=None)
