@@ -76,11 +76,13 @@ class _Serializable:
     __slots__ = ()
 
     def primitive(self, *, lazy: bool = False, name: ReprT = None) -> Mapping[str, Any]:
-        return resolver.primitive(self, lazy=lazy, name=name)
+        return resolver.primitive(self, lazy=lazy, name=name)  # type: ignore
 
-    def tojson(self, *, indent: int = 0, ensure_ascii: bool = False, **kwargs) -> str:
+    def tojson(
+        self, *, indent: int = 0, ensure_ascii: bool = False, **kwargs
+    ) -> Union[str, bytes]:
         return dumps(
-            self.primitive(lazy=True),
+            self.primitive(),
             indent=indent,
             ensure_ascii=ensure_ascii,
             **kwargs,
@@ -124,7 +126,7 @@ class StringFormat(str, enum.Enum):
     IPV6 = "ipv6"
 
 
-@slotted
+@slotted(dict=True)
 @dataclasses.dataclass(frozen=True, repr=False)
 class BaseSchemaField(_Serializable):
     """The base JSON Schema Field."""
@@ -384,7 +386,7 @@ SCHEMA_FIELD_FORMATS = TypeMap(
         ipaddress.IPv4Address: StrSchemaField(format=StringFormat.IPV4),
         ipaddress.IPv6Address: StrSchemaField(format=StringFormat.IPV6),
         str: StrSchemaField(),
-        AnyStr: StrSchemaField(),
+        AnyStr: StrSchemaField(),  # type: ignore
         Text: StrSchemaField(),
         bytes: StrSchemaField(),
         bool: BooleanSchemaField(),
@@ -396,6 +398,6 @@ SCHEMA_FIELD_FORMATS = TypeMap(
         frozenset: ArraySchemaField(uniqueItems=True, additionalItems=False),
         dict: ObjectSchemaField(),
         type(None): NullSchemaField(),
-        Literal: BaseSchemaField(),
+        Literal: BaseSchemaField(),  # type: ignore
     }
 )
