@@ -36,7 +36,7 @@ from typing import (
 
 from typic import util, checks, gen, types
 from typic.common import DEFAULT_ENCODING
-from typic.compat import Literal
+from typic.compat import Literal, Record
 from .common import (
     SerializerT,
     SerdeConfig,
@@ -49,8 +49,7 @@ if TYPE_CHECKING:  # pragma: nocover
     from .resolver import Resolver
 
 
-class SerializationValueError(ValueError):
-    ...
+class SerializationValueError(ValueError): ...
 
 
 _decode = methodcaller("decode", DEFAULT_ENCODING)
@@ -85,7 +84,7 @@ class SerFactory:
         types.SecretStr: cast(SerializerT, attrgetter("secret")),
         types.URL: str,
         uuid.UUID: str,
-        decimal.Decimal: float,
+        decimal.Decimal: str,
         bytes: cast(SerializerT, _decode),
         bytearray: cast(SerializerT, _decode),
         datetime.date: cast(SerializerT, util.isoformat),
@@ -104,7 +103,7 @@ class SerFactory:
         Iterable,
         Iterable_abc,
     )
-    _DICTITER = (dict, Mapping, Mapping_abc, MappingProxyType, types.FrozenDict)
+    _DICTITER = (dict, Mapping, Mapping_abc, MappingProxyType, types.FrozenDict, Record)
     _PRIMITIVES = (str, int, bool, float, type(None), type(...))
     _DYNAMIC = frozenset(
         {Union, Any, inspect.Parameter.empty, dataclasses.MISSING, ClassVar, Literal}
@@ -201,14 +200,12 @@ class SerFactory:
             ns["case"] = annotation.serde.flags.case.transformer
             ksercall = f"case({ksercall})"
         gencall = f"({ksercall}, vser(v)) for k, v in o.items()"
+        itercall = f"{ksercall}: vser(v) for k, v in o.items()"
         if annotation.serde.flags.omit:
             ns["omit"] = annotation.serde.flags.omit
-            gencall = f"{gencall} if v not in omit"
-        func.l(
-            f"gen = ({gencall})",
-            **ns,
-        )
-        func.l(f"{gen.Keyword.RET} gen if lazy else {{k: v for k, v in gen}}")
+            gencall += "if v not in omit"
+            itercall += "if v not in omit"
+        func.l(f"{gen.Keyword.RET} ({gencall}) if lazy else {{{itercall}}}", **ns)
 
     def _build_class_serializer(
         self,
@@ -240,12 +237,13 @@ class SerFactory:
             f = "transforms.get(f, f)"
         # Define the generator expression.
         gencall = f"({f}, fields_ser[f](v)) for f, v in iterator(o) if f in fields_out"
+        itercall = f"{f}: fields_ser[f](v) for f, v in iterator(o) if f in fields_out"
         if annotation.serde.flags.omit:
             ns["omit"] = annotation.serde.flags.omit
-            gencall = f"{gencall} and v not in omit"
+            gencall += " and v not in omit"
+            itercall += " and v not in omit"
 
-        func.l(f"gen = ({gencall})", **ns)
-        func.l(f"{gen.Keyword.RET} gen if lazy else {{f: v for f, v in gen}}")
+        func.l(f"{gen.Keyword.RET} ({gencall}) if lazy else {{{itercall}}}", **ns)
 
     def _compile_enum_serializer(self, annotation: Annotation) -> SerializerT:
         origin: Type[enum.Enum] = cast(Type[enum.Enum], annotation.resolved_origin)
@@ -253,13 +251,38 @@ class SerFactory:
         # If we can predict a single type the return the serializer for that
         if len(ts) == 1:
             t = ts.pop()
-            va = self.resolver.annotation(t, flags=annotation.serde.flags)
+            va = self.resolver.annotation(
+                t,
+                flags=annotation.serde.flags,
+                is_optional=annotation.optional,
+                is_strict=annotation.strict,
+                parameter=annotation.parameter,
+                default=annotation.parameter.default,
+            )
             vser = self.factory(va)
+            if va.optional:
 
-            def serializer(
-                o: enum.Enum, *, lazy: bool = False, name: util.ReprT = None, _vser=vser
-            ):
-                return _vser(o.value, lazy=lazy, name=name)
+                def serializer(
+                    o: Optional[enum.Enum],
+                    *,
+                    lazy: bool = False,
+                    name: util.ReprT = None,
+                    _vser=vser,
+                ):
+                    if o is None:
+                        return o
+                    return _vser(o.value, lazy=lazy, name=name)
+
+            else:
+
+                def serializer(
+                    o: enum.Enum,
+                    *,
+                    lazy: bool = False,
+                    name: util.ReprT = None,
+                    _vser=vser,
+                ):
+                    return _vser(o.value, lazy=lazy, name=name)
 
             return cast(SerializerT, serializer)
         # Else default to lazy serialization
